<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:strip-space elements="*"/>
	<xsl:output method="html" indent="yes" encoding="utf-8"/>

	<xsl:template match="PAYMENT-SYSTEMS">
		<script type="text/javascript" src="/modules/Eshop/js/payment.js?{$version}.{$build}"></script>
		<xsl:apply-templates select="@IS-MODIFIED"/>
		<table border="0" style="width:100%;" class="sb-page">
			<tr>
				<td style="width:20%;">
					<span><b><xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/CURRENCY-SELECTED"/></b></span>
				</td>
				<td style="width:10%;" ><xsl:value-of select="@CURRENCY"/></td>
				<td style="width:70%;" align="right">
					<xsl:call-template name="BUTTON-CONTROL">
						<xsl:with-param name="title"><xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/CHANGE-CURRENCY-SETTINGS"/></xsl:with-param>
						<xsl:with-param name="action">
							self.sbApplyChangesObject.registerForcedSaving();
							sbNavigationObject.go('<xsl:value-of select="$baseUrl"/>/Wizard/Edit/Modules/Eshop/Payment/Currency');
						</xsl:with-param>
					</xsl:call-template>
				</td>
			</tr>
		</table>
		<table border="0" style="width:100%;" class="sb-page">
			<xsl:apply-templates select="LIST"/>
		</table>
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/@IS-MODIFIED[.='yes']">
		<script type="text/javascript">
			self.sbApplyChangesObject.registerChange();
		</script>
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*">
		<tr>
			<td>
				<fieldset class="sb-toolbar-fieldset">
				<legend class="sb-label-toolbar-title"></legend>
				<table border="0" style="width:100%;" class="sb-page">
				<tr>
					<td width="20%"><xsl:value-of select="@NAME"/></td>
					<td colspan="2">
						<input type="checkbox">
							<xsl:if test="@CURRENCY-SUPPORTED='0'"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
							<xsl:if test="@ACTIVE=1"><xsl:attribute name="checked">true</xsl:attribute></xsl:if>
							<xsl:attribute name="id"><xsl:value-of select="@CODE"/></xsl:attribute>
							<xsl:attribute name="name"><xsl:value-of select="@CODE"/></xsl:attribute>
							<xsl:attribute name="onclick">changePaymentStatus("<xsl:value-of select="@CODE"/>", this.checked); self.sbApplyChangesObject.registerChange();</xsl:attribute>
						</input>
					</td>
				</tr>
				<xsl:apply-templates select="REGISTRATION"/>
				<xsl:apply-templates select="FIELDS"/>
				</table>
				</fieldset>
			</td>
		</tr>
	</xsl:template>
	
	<xsl:template match="PAYMENT-SYSTEMS/LIST/BLUEPAY/REGISTRATION">
	<tr>
		<td width="20%"><xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/BLUEPAY-REGISTRATION-TITLE"/></td>
		<td width="10%"></td>
		<td>
			<a href="#">
				<xsl:attribute name="onclick">
					self.sbApplyChangesObject.registerForcedSaving();
					sbNavigationObject.go('<xsl:value-of select="$baseUrl"/>/Wizard/Edit/Modules/Eshop/Payment/BluePayRegistration');
				</xsl:attribute>
				<xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/BLUEPAY-REGISTRATION-NOW"/>
			</a>
		</td>
	</tr>
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/ITEM">
		<tr>
			<td width="20%">
				<xsl:value-of select="@TITLE"/>
				<span style="color:red; width:10px;">&#160;*</span>
			</td>
			<td width="10%"></td>
			<td align="right">
				<xsl:choose>
					<xsl:when test="@TYPE='textarea'">
						<textarea style="width:100%; height:50px" class="sb-control-input-input">
							<xsl:if test="./../../@ACTIVE=0"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
							<xsl:attribute name="name"><xsl:value-of select="@NAME"/></xsl:attribute>
							<xsl:attribute name="id"><xsl:value-of select="@NAME"/></xsl:attribute>
							<xsl:attribute name="onclick">self.sbApplyChangesObject.registerChange();</xsl:attribute>
							<xsl:value-of select="@VALUE"/>
						</textarea>
					</xsl:when>
					<xsl:otherwise>
						<input type="text" class="sb-control-input-input" style="width:100%">
							<xsl:if test="./../../@ACTIVE=0"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
							<xsl:attribute name="name"><xsl:value-of select="@NAME"/></xsl:attribute>
							<xsl:attribute name="id"><xsl:value-of select="@NAME"/></xsl:attribute>
							<xsl:attribute name="value"><xsl:value-of select="@VALUE"/></xsl:attribute>
							<xsl:attribute name="onclick">self.sbApplyChangesObject.registerChange();</xsl:attribute>
						</input>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/CUSTOM/FIELDS">
		<script type="text/javascript" src="/modules/Eshop/js/customPayment.js?{$version}.{$build}"></script>
		<xsl:apply-templates select="CONTROL"/>
		<script type="text/javascript">
			self.customSettingsOwnerList = new CustomSettingsOwnerList('<xsl:value-of select="../@CODE"/>');
			<xsl:apply-templates select="CONTROL" mode="paymentInit"/>
		</script>
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL[@FIELD-TYPE='string' or @FIELD-TYPE='text' or @FIELD-TYPE='password']" mode="paymentInit">
		self.customSettingsOwnerList.register(new CustomSettingsObjectText('<xsl:value-of select="@NAME"/>', '<xsl:value-of select="@REQUIRE"/>'));
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL[@FIELD-TYPE='email']" mode="paymentInit">
		self.customSettingsOwnerList.register(new CustomSettingsObjectMail('<xsl:value-of select="@NAME"/>', '<xsl:value-of select="@REQUIRE"/>'));
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL[@FIELD-TYPE='double']" mode="paymentInit">
		self.customSettingsOwnerList.register(new CustomSettingsObjectDouble('<xsl:value-of select="@NAME"/>', '<xsl:value-of select="@REQUIRE"/>', '<xsl:value-of select="@DECIMAL-POINT"/>'));
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL[@FIELD-TYPE='currency']" mode="paymentInit">
		self.customSettingsOwnerList.register(new CustomSettingsObjectCurrency('<xsl:value-of select="@NAME"/>', '<xsl:value-of select="@REQUIRE"/>', '<xsl:value-of select="@DECIMAL-POINT"/>'));
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL[@FIELD-TYPE='integer']" mode="paymentInit">
		self.customSettingsOwnerList.register(new CustomSettingsObjectInteger('<xsl:value-of select="@NAME"/>', '<xsl:value-of select="@REQUIRE"/>'));
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL[@FIELD-TYPE='numeric']" mode="paymentInit">
		self.customSettingsOwnerList.register(new CustomSettingsObjectNumeric('<xsl:value-of select="@NAME"/>', '<xsl:value-of select="@REQUIRE"/>'));
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL[@FIELD-TYPE='phone']" mode="paymentInit">
		self.customSettingsOwnerList.register(new CustomSettingsObjectPhone('<xsl:value-of select="@NAME"/>', '<xsl:value-of select="@REQUIRE"/>'));
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL[@FIELD-TYPE='date']" mode="paymentInit">
		self.customSettingsOwnerList.register(new CustomSettingsObjectDate('<xsl:value-of select="@NAME"/>', '<xsl:value-of select="@REQUIRE"/>'));
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL">
		<tr>
			<td width="20%">
				<xsl:value-of select="@TITLE"/>
				<xsl:if test="@REQUIRE = 'on'">
					<span style="color:red; width:10px;">&#160;*</span>
				</xsl:if>
			</td>
			<td width="10%"></td>
			<td align="right">
				<xsl:apply-templates select="." mode="paymentInput"/>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL[@TYPE='TEXT']" mode="paymentInput">
		<textarea style="width:100%; height:50px" class="sb-control-input-input">
			<xsl:if test="./../../@ACTIVE=0"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
			<xsl:attribute name="name"><xsl:value-of select="@NAME"/></xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@NAME"/></xsl:attribute>
			<xsl:attribute name="onclick">self.sbApplyChangesObject.registerChange();</xsl:attribute>
			<xsl:value-of select="."/>
		</textarea>
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL[@TYPE='INPUT']" mode="paymentInput">
		<input type="text" class="sb-control-input-input" style="width:100%">
			<xsl:if test="./../../@ACTIVE=0"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
			<xsl:attribute name="name"><xsl:value-of select="@NAME"/></xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@NAME"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
			<xsl:attribute name="onclick">self.sbApplyChangesObject.registerChange();</xsl:attribute>
		</input>
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL[@TYPE='PASSWORD']" mode="paymentInput">
		<input type="password" class="sb-control-input-input" style="width:100%">
			<xsl:if test="./../../@ACTIVE=0"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
			<xsl:attribute name="name"><xsl:value-of select="@NAME"/></xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@NAME"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
			<xsl:attribute name="onclick">self.sbApplyChangesObject.registerChange();</xsl:attribute>
		</input>
	</xsl:template>

	<xsl:template match="PAYMENT-SYSTEMS/LIST/*/FIELDS/CONTROL[@TYPE='DATE']" mode="paymentInput">
		<table border="0" style="width:100%;">
			<tr>
				<td style="width: 1%; white-space: nowrap;">
					<xsl:value-of select="@MONTH-TITLE"/>
				</td>
				<td style="white-space: nowrap;">
					<input type="text" class="sb-control-input-input" style="width:100%">
						<xsl:if test="./../../@ACTIVE=0"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
						<xsl:attribute name="name"><xsl:value-of select="@NAME"/>month</xsl:attribute>
						<xsl:attribute name="id"><xsl:value-of select="@NAME"/>month</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="@MONTH"/></xsl:attribute>
						<xsl:attribute name="onclick">self.sbApplyChangesObject.registerChange();</xsl:attribute>
					</input>
				</td>
				<td style="width: 1%; white-space: nowrap; padding: 0px 0px 0px 10px;">
					<xsl:value-of select="@DAY-TITLE"/>
				</td>
				<td style="white-space: nowrap;">
					<input type="text" class="sb-control-input-input" style="width:100%">
						<xsl:if test="./../../@ACTIVE=0"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
						<xsl:attribute name="name"><xsl:value-of select="@NAME"/>day</xsl:attribute>
						<xsl:attribute name="id"><xsl:value-of select="@NAME"/>day</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="@DAY"/></xsl:attribute>
						<xsl:attribute name="onclick">self.sbApplyChangesObject.registerChange();</xsl:attribute>
					</input>
				</td>
				<td style="width: 1%; white-space: nowrap; padding: 0px 0px 0px 10px;">
					<xsl:value-of select="@YEAR-TITLE"/>
				</td>
				<td style="white-space: nowrap;">
					<input type="text" class="sb-control-input-input" style="width:100%">
						<xsl:if test="./../../@ACTIVE=0"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
						<xsl:attribute name="name"><xsl:value-of select="@NAME"/>year</xsl:attribute>
						<xsl:attribute name="id"><xsl:value-of select="@NAME"/>year</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="@YEAR"/></xsl:attribute>
						<xsl:attribute name="onclick">self.sbApplyChangesObject.registerChange();</xsl:attribute>
					</input>
				</td>
			</tr>
		</table>
	</xsl:template>

</xsl:stylesheet>